ComputedScoped<Result> class

Implemented types
Available extensions

Constructors

ComputedScoped(RefComputer<Result> compute, {bool? concurrent})

Properties

compute RefComputer<Result>
finalinherited
concurrent bool?
finalinherited
dependencyMap Map<ValueRef, ValueRef>
getter/setter pair
fullDependencyMap Map<ValueRef, ValueRef>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → Result
The current value of the object. When the value changes, the callbacks registered with addListener will be invoked.
no setterinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object notifies its listeners.
inherited
dispose() → void
Discards any resources used by the object. After this is called, the object is not in a usable state and should be discarded (calls to addListener will throw after the object is disposed).
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
read<G extends GetAny>(G get, {bool autoVsync = true, bool useScope = true}) → G
override
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies.
inherited
select<R, T>(GetT<T> get, R selector(T value), {bool autoVsync = true, bool useScope = true}) → R
override
toString() String
A string representation of this object.
inherited
vsync<G extends GetAny>(G get, {bool useScope = true}) → G

Available on ComputeRef, provided by the VsyncRef extension

watch<T>(GetT<T> get, {bool autoVsync = true, bool useScope = true}) → T
override

Operators

operator ==(Object other) bool
The equality operator.
inherited