DisposeGuard mixin
Mixin for Get objects with a dispose method.
Ref will automatically free associated resources when its associated
HookWidget is no longer in use, so the dispose() method of a
ValueNotifier or AnimationController is unnecessary.
The DisposeGuard.dispose method throws an error.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → void -
Ref will automatically free associated resources when its associated
HookWidget is no longer in use, so the
dispose()method of a ValueNotifier or AnimationController is unnecessary. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited