GetProxy<T, L extends Listenable>
extension type
Encapsulates any Listenable, using the provided callback to retrieve a value.
- on
-
- ProxyNotifier<
T, L>
- ProxyNotifier<
- Implemented types
-
- Get<
T, ProxyNotifier< T, L> >
- Get<
Properties
- addListener → void
-
Don't add a listener directly!
Prefer using Ref.watch or something similar.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- removeListener → void
-
Don't remove a listener directly!
Prefer using Ref.watch or something similar.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → T
-
The current value of the object. When the value changes, the callbacks
registered with addListener will be invoked.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited