GetScopeError constructor
GetScopeError(
- String message
Might as well use a fun little class for the scope errors!
Implementation
GetScopeError(super.message);
Might as well use a fun little class for the scope errors!
GetScopeError(super.message);