GetValue<T> extension type

Encapsulates a ValueNotifier.

on
Implemented types
Available extensions

Properties

addListener → void
Don't add a listener directly! Prefer using Ref.watch or something similar.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
removeListener → void
Don't remove a listener directly! Prefer using Ref.watch or something similar.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value ↔ T
The current value of the object. When the value changes, the callbacks registered with addListener will be invoked.
getter/setter pairinherited-getter

Methods

emit(T? newValue) → void
Sets a new value and emits a notification.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toggle([dynamic _]) → void

Available on GetValue<bool>, provided by the ToggleValue extension

Convenience method for toggling a bool value back and forth.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited