GetVsync<T, A extends Animation<T> >
extension type
Encapsulates an Animation.
- on
-
- A
- Implemented types
- Implementers
Properties
- addListener → void
-
Don't add a listener directly!
Prefer using Ref.watch or something similar.
no setteroverride
- addStatusListener → void
-
Don't add a listener directly!
Prefer using Ref.watch or something similar.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isAnimating → bool
-
Whether this animation is running in either direction.
no setterinherited
- isCompleted → bool
-
Whether this animation is stopped at the end.
no setterinherited
- isDismissed → bool
-
Whether this animation is stopped at the beginning.
no setterinherited
- isForwardOrCompleted → bool
-
Whether the current aim of the animation is toward completion.
no setterinherited
- maybeVsync → Vsync?
-
The Vsync associated with this animation.
no setter
- removeListener → void
-
Don't remove a listener directly!
Prefer using Ref.watch or something similar.
no setteroverride
- removeStatusListener → void
-
Don't remove a listener directly!
Prefer using Ref.watch or something similar.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → AnimationStatus
-
The current status of this animation.
no setterinherited
- value → T
-
The current value of the object. When the value changes, the callbacks
registered with addListener will be invoked.
no setterinherited
Methods
-
addStatusListener(
AnimationStatusListener listener) → void -
Calls listener every time the status of the animation changes.
inherited
-
drive<
U> (Animatable< U> child) → Animation<U> -
Chains a Tween (or CurveTween) to this Animation.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeStatusListener(
AnimationStatusListener listener) → void -
Stops calling the listener every time the status of the animation changes.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
toStringDetails(
) → String -
Provides a string describing the status of this object, but not including
information about the object itself.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited