lowerBound property
double
get
lowerBound
The value at which this animation is deemed to be dismissed.
Implementation
double get lowerBound => _hooked.lowerBound;
The value at which this animation is deemed to be dismissed.
double get lowerBound => _hooked.lowerBound;