upperBound property
double
get
upperBound
The value at which this animation is deemed to be completed.
Implementation
double get upperBound => _hooked.upperBound;
The value at which this animation is deemed to be completed.
double get upperBound => _hooked.upperBound;