curve property

Curve get curve

Determines how quickly the animation speeds up and slows down.

For instance, if this is set to Curves.easeOutExpo, the majority of the change to the value happens right away, whereas Curves.easeIn would start slowly and then pick up speed toward the end.

Implementation

Curve get curve => _hooked.curve;
set curve (Curve newValue)

Implementation

set curve(Curve newValue) {
  _hooked.curve = curve;
}