duration property
Duration
get
duration
The length of time this animation should last.
The duration can be adjusted at any time, but modifying it while an animation is active could result in sudden visual changes.
Implementation
Duration get duration => _hooked.duration;
set
duration
(Duration newValue)
Implementation
set duration(Duration newValue) {
_hooked.duration = newValue;
}