ScopedGet<T> class

Creates pseudo-Get objects that throw when properties are accessed.

ScopedGet can be used to define a top-level Get object, to ensure that it's only used in the correct scope.

Implemented types

Constructors

ScopedGet()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → T
The current value of the object. When the value changes, the callbacks registered with addListener will be invoked.
no setterinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object notifies its listeners.
inherited
noSuchMethod(Invocation invocation) → Never
ScopedGet "implements" any interface by throwing an error any time an attempt is made to access an instance member.
override
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

async<T>() GetAsync<T>
Placeholder for an AsyncNotifier.
compute<Result>() GetComputed<Result>
Placeholder for a ComputedNotifier.
it<T>([dynamic _]) GetValue<T>
Placeholder for a ValueNotifier.
list<E>([dynamic _]) GetList<E>
Placeholder for a ListNotifier.
map<K, V>([dynamic _]) GetMap<K, V>
Placeholder for a MapNotifier.
proxy<T, L extends Listenable>() GetProxy<T, L>
Placeholder for a ProxyNotifier.
set<E>([dynamic _]) GetSet<E>
Placeholder for a SetNotifier.
stream<T>() GetAsync<T>
Placeholder for an AsyncNotifier.
vsync() GetVsyncDouble
Placeholder for an AnimationController.
vsyncValue<T>() GetVsyncValue<T>
Placeholder for a ValueAnimation.