noSuchMethod method
ScopedGet "implements" any interface by throwing an error any time an attempt is made to access an instance member.
Implementation
@override
Never noSuchMethod(Invocation invocation) {
throw GetScopeError('Attempted to access ${invocation.memberName} on $this');
}