ObjectRef<T> class

A class that stores a single value.

This is similar to a ValueNotifier but does not send any notifications when the value changes.

It is typically instantiated by useRef.

Constructors

ObjectRef(T value)
Stores a single value.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value ↔ T
A mutable property that will be preserved across rebuilds.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited