HookData<Result> class abstract

This class makes it easier for a Hook to work with a complex data model.

Annotations

Constructors

HookData({Object? key})
Creates a data object to be passed into a Hook.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
key Object?
Changing this key's value will cause the Hook to reset.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createHook() Hook<Result, HookData<Result>>
Generally returns an empty constructor for a Hook subclass.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

use<Result>(HookData<Result> hookData, {String? debugLabel}) → Result
Uses a HookData instance to create a Hook and return its result.