inherit property

bool inherit
final

Whether this GetScope should also include substitutes from an ancestor scope, if applicable.

Ancestor substitutes are ignored if the same value is substituted in this scope.

Implementation

final bool inherit;