subGet method
Uses a different Get object to create a Substitution which can be passed into a GetScope.
Implementation
Substitution<V> subGet(GetV<V> newGet, {bool autoDispose = true}) {
return sub(newGet.hooked, autoDispose: autoDispose);
}
Uses a different Get object to create a Substitution which can be passed into a GetScope.
Substitution<V> subGet(GetV<V> newGet, {bool autoDispose = true}) {
return sub(newGet.hooked, autoDispose: autoDispose);
}