vsync<A extends GetVsyncAny> static method

A vsync<A extends GetVsyncAny>(
  1. A get, {
  2. bool useScope = true,
  3. bool watching = false,
})

Manages this Get object's Vsync.

The animation will inherit the DefaultAnimationStyle's ambient style along with information from the TickerMode regarding whether its Ticker should be muted.

If watching is true, each notification sent by the animation triggers a rebuild.

Implementation

static A vsync<A extends GetVsyncAny>(A get, {bool useScope = true, bool watching = false}) {
  if (useScope) get = GetScope.of(useContext(), get);
  useListenable(watching ? get : null);

  use(_VsyncHook.new, key: get, data: get, debugLabel: 'Ref.vsync');
  return get;
}