replacement property

V get replacement

A ValueListenable of the same type as the ref which will be referenced in its place by methods like Ref.watch called from descendant widgets.

Implementation

V get replacement;