AsyncNotifier<T> class

A variation of ValueNotifier, set up for AsyncSnapshot data.

The connectionState can be set directly without triggering a notification.

Implemented types
Mixed-in types
Implementers

Constructors

AsyncNotifier(AsyncSnapshot<T> _value)
Creates a ChangeNotifier that broadcasts AsyncSnapshots.
AsyncNotifier.initialData(T? data)
Creates an async notifier based on initial data.

Properties

connectionState ConnectionState
Current state of connection to the asynchronous computation.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value AsyncSnapshot<T>
The current value stored in this notifier.
getter/setter pairoverride

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object. After this is called, the object is not in a usable state and should be discarded (calls to addListener will throw after the object is disposed).
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited