ProxyNotifier<T, L extends Listenable> class
Transforms any Listenable into a ValueListenable.
- Inheritance
-
- Object
- ProxyNotifierBase<
T> - ProxyNotifier
Constructors
- ProxyNotifier(L listenable, T getValue(L))
- Transforms any Listenable into a ValueListenable.
Properties
- concurrent ↔ bool?
-
Whether this notifier should immediately update its value
upon receiving a notification.
getter/setter pairinherited
- getValue → T Function(L)
-
Retrieves a value using the provided listenable.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- listenable → Listenable
-
The input Listenable object.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → T
-
The current value of the object. When the value changes, the callbacks
registered with addListener will be invoked.
no setteroverride
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object notifies its listeners.
inherited
-
dispose(
) → void -
Discards any resources used by the object. After this is called, the
object is not in a usable state and should be discarded (calls to
addListener will throw after the object is disposed).
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that the
object notifies.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited