ProxyNotifier9<T, L1, L2, L3, L4, L5, L6, L7, L8, L9> class
Transforms nine values into a ValueListenable.
At least 1 of these nine values should be a Listenable,
so that the ProxyNotifier knows when to send its own notifications.
- Inheritance
-
- Object
- ProxyNotifierBase<
T> - ProxyNotifier9
Constructors
- ProxyNotifier9(L1 l1, L2 l2, L3 l3, L4 l4, L5 l5, L6 l6, L7 l7, L8 l8, L9 l9, T getValue(L1 l1, L2 l2, L3 l3, L4 l4, L5 l5, L6 l6, L7 l7, L8 l8, L9 l9), {bool? concurrent = false})
- Transforms nine values into a ValueListenable.
Properties
- concurrent ↔ bool?
-
Whether this notifier should immediately update its value
upon receiving a notification.
getter/setter pairinherited
- getValue → T Function(L1 l1, L2 l2, L3 l3, L4 l4, L5 l5, L6 l6, L7 l7, L8 l8, L9 l9)
-
Retrieves a value using the provided getValue function with nine values.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- l1 → L1
-
final
- l2 → L2
-
final
- l3 → L3
-
final
- l4 → L4
-
final
- l5 → L5
-
final
- l6 → L6
-
final
- l7 → L7
-
final
- l8 → L8
-
final
- l9 → L9
-
final
- listenable → Listenable
-
The input Listenable object.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → T
-
The current value of the object. When the value changes, the callbacks
registered with addListener will be invoked.
no setteroverride
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object notifies its listeners.
inherited
-
dispose(
) → void -
Discards any resources used by the object. After this is called, the
object is not in a usable state and should be discarded (calls to
addListener will throw after the object is disposed).
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that the
object notifies.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited