concurrent property

bool? concurrent
getter/setter pair

Whether this notifier should immediately update its value upon receiving a notification.

Set as true when a single Listenable is proxied. Otherwise the behavior depends on the SchedulerPhase, ensuring that dependents are notified on time while avoiding duplicate notifications when possible.

Implementation

bool? concurrent;