maintainSpeed property

bool maintainSpeed
final

If set to true, an animation that covers half the distance (e.g. animateTo(1.0, from: 0.5)) will finish in half the time.

If false, the specified duration will always apply, so a transition from 0.5 to 1.0 will appear "slower" than from 0.0 to 1.0.

Implementation

final bool maintainSpeed;