curve property

Curve curve
getter/setter pair

Determines how quickly the animation speeds up and slows down.

For instance, if this is set to Curves.easeOutExpo, the majority of the change to the value happens right away, whereas Curves.easeIn would start slowly and then pick up speed toward the end.

Implementation

Curve curve;