duration property

Duration duration
getter/setter pair

The length of time this animation should last.

The duration can be adjusted at any time, but modifying it while an animation is active could result in sudden visual changes.

Implementation

Duration duration;