value property

  1. @override
T get value
override

The current value of the animation.

Implementation

@override
T get value => _value;
set value (T newTarget)

Rather than updating immediately, changes to the value will animate each time a new target is set, using the provided duration, curve, and lerp callback.

To create an immediate change to the value, consider calling animateTo with a non-null from parameter, or calling jumpTo.

Implementation

set value(T newTarget) {
  animateTo(newTarget);
}