preferredSize property

  1. @override
Size get preferredSize
override

A size whose height is the sum of toolbarHeight and the bottom widget's preferred height.

Scaffold uses this size to set its app bar's height.

Implementation

@override
Size get preferredSize => _PreferredAppBarSize(toolbarHeight, bottom?.preferredSize.height);