TextGetter<T> class abstract

A widget displaying a string representation of a Get object's value.

Inheritance

Constructors

TextGetter(GetT<T> get, {Key? key, String describe(T value), TextStyle style, TextAlign? align, int? maxLines, TextOverflow? overflow, bool softWrap, StrutStyle? strutStyle, TextHeightBehavior? textHeightBehavior, TextScaler? textScaler, TextWidthBasis? textWidthBasis})
Creates a widget displaying a string representation of a Get object's value.
const
factory
TextGetter.construct({Key? key, String describe(T value) = _describe, TextStyle style = const TextStyle(), TextAlign? align, int? maxLines, TextOverflow? overflow, bool? softWrap, StrutStyle? strutStyle, TextHeightBehavior? textHeightBehavior, TextScaler? textScaler, TextWidthBasis? textWidthBasis})
Initializes fields for subclasses.
const
TextGetter.ref(ValueGetter<GetT<T>> get, {Key? key, String describe(T value), TextStyle style, TextAlign? align, int? maxLines, TextOverflow? overflow, bool softWrap, StrutStyle? strutStyle, TextHeightBehavior? textHeightBehavior, TextScaler? textScaler, TextWidthBasis? textWidthBasis})
Creates a widget displaying a string representation of a Get object's value.
const
factory

Properties

align TextAlign?
How the text should be aligned horizontally.
final
child Widget?
The widget below this widget in the tree.
finalinherited
describe String Function(T value)
Optionally turns the Get object's value into a String description.
final
get GetT<T>
The Get object to display in text form.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
maxLines int?
An optional maximum number of lines for the text to span, wrapping if necessary. If the text exceeds the given number of lines, it will be truncated according to overflow.
final
overflow TextOverflow?
How visual overflow should be handled.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
softWrap bool?
Whether the text should break at soft line breaks.
final
strutStyle StrutStyle?
The strut style to use. Strut style defines the strut, which sets minimum vertical layout metrics.
final
style TextStyle
The TextStyle to apply to this text.
final
textHeightBehavior TextHeightBehavior?
Defines how to apply TextStyle.height over and under text.
final
textScaler TextScaler?
The font scaling strategy to use when laying out and rendering the text.
final
textWidthBasis TextWidthBasis?
Defines how to measure the width of the rendered text.
final

Methods

createElement() SingleChildRenderObjectElement
RenderObjectWidgets always inflate to a RenderObjectElement subclass.
inherited
createRenderObject(BuildContext context) RenderObject
Creates an instance of the RenderObject class that this RenderObjectWidget represents, using the configuration described by this RenderObjectWidget.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didUnmountRenderObject(covariant RenderObject renderObject) → void
This method is called when a RenderObject that was previously associated with this widget is removed from the render tree. The provided RenderObject will be of the same type as the one created by this widget's createRenderObject method.
inherited
listen(covariant RenderParagraph renderObject, T value) → void
Used to make a closure for Listenable.addListener.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render(BuildContext context, T value) RenderObject
Creates a RenderObject (which is then passed to createRenderObject).
override
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited
updateRenderObject(BuildContext context, covariant RenderParagraph renderObject) → void
Copies the configuration described by this RenderObjectWidget to the given RenderObject, which will be of the same type as returned by this object's createRenderObject.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited