widgets/hook_widgets library

Classes

HookBuilder
A HookWidget that delegates its build to a callback.
HookWidget
A variation of a StatelessWidget that can call Hook functions in its HookWidget.build method.
StatefulHookWidget
A variation of a StatefulWidget that can call Hook functions in its State.build method.