widgets/ref_paint library

Classes

RefPaint
A variation of CustomPaint that interfaces with Get objects.

Extension Types

PainterRef
A reference used in RefPaint.hitTest calls.
PaintingRef
An interface used by RefPaint.paint and RefPaint.buildSemantics.

Typedefs

RefPaintCallback = void Function(PaintingRef ref)
Signature for the callback within a RefPaint widget that paints a UI element, using a Canvas retrieved via PaintingRef.stageCanvas.
RefPaintHitTest = bool? Function(PainterRef ref, Offset location)
Signature for a callback that determines whether a RefPaint widget will absorb a hit test. If the function or its output is null, the widget defers to the default behavior as defined in RefPaint.hitTest.
RefPaintSemanticsBuilder = List<CustomPainterSemantics> Function(PaintingRef ref)
Builds semantics information describing the picture drawn by a RefPaintCallback. Each CustomPainterSemantics in the returned list is converted into a SemanticsNode by copying its properties.