PaintingRef extension type

An interface used by RefPaint.paint and RefPaint.buildSemantics.

on
  • _RefPainterElement
Implemented types

Properties

context BuildContext
Use caution when accessing the BuildContext, since any update from an InheritedWidget will trigger a repaint unconditionally.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size Size
The Size of the painter's canvas.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read<G extends GetAny>(G get, {bool createDependency = true, bool throwIfMissing = false}) → G
Returns the relevant Get object based on the current context.
inherited
select<Result, T>(GetT<T> get, Result selector(T value), {bool useScope = true}) → Result
Returns the selector's output, and triggers a re-render when it changes.
stageCanvas({bool isComplex = false, bool willChange = false}) Canvas
Called by a RefPaint widget to stage a Canvas on which to paint.
toString() String
A string representation of this object.
inherited
vsync<V extends GetVsyncAny>(V getVsync, {bool useScope = true, bool watch = false}) → V
Registers a GetVsync object with this RefPaint's context, in a fashion similar to Ref.vsync.
watch<T>(GetT<T> get) → T
Returns the Get object's value, and triggers a re-render when it changes.

Operators

operator ==(Object other) bool
The equality operator.
inherited