RefPaintHitTest typedef

RefPaintHitTest = bool? Function(PainterRef ref, Offset location)

Signature for a callback that determines whether a RefPaint widget will absorb a hit test. If the function or its output is null, the widget defers to the default behavior as defined in RefPaint.hitTest.

Implementation

typedef RefPaintHitTest = bool? Function(PainterRef ref, Offset location);