RefPaintSemanticsBuilder typedef

RefPaintSemanticsBuilder = List<CustomPainterSemantics> Function(PaintingRef ref)

Builds semantics information describing the picture drawn by a RefPaintCallback. Each CustomPainterSemantics in the returned list is converted into a SemanticsNode by copying its properties.

The returned list must not be mutated after this function completes. To change the semantic information, the function must return a new list instead.

Implementation

typedef RefPaintSemanticsBuilder = List<CustomPainterSemantics> Function(PaintingRef ref);