widgets/render_get library
Classes
-
RenderGet<
Render extends RenderObject> - A simple widget that subscribes to a Get object and updates a RenderObject accordingly.
- RenderGetBase
- Extend this class to create a widget with a single child.
-
RenderScopedGetBase<
T> - Extend this class to create a widget with a single child.