ref/get/get library

Classes

ComputedScoped<Result>
ComputeRef
HookRef
ScopedGet<T>
Creates pseudo-Get objects that throw when properties are accessed.

Mixins

DisposeGuard
Mixin for Get objects with a dispose method.

Extension Types

Get
Encapsulates a ValueListenable object with an interface for easy updates and automatic lifecycle management.
GetAsync
Encapsulates an AsyncNotifier.
GetComputed
Encapsulates a Listenable which notifies based on a RefComputer callback.
GetList
Encapsulates a ListNotifier and can be used as a List directly.
GetMap
Encapsulates a MapNotifier and can be used as a Map directly.
GetProxy
Encapsulates any Listenable, using the provided callback to retrieve a value.
GetSet
Encapsulates a SetNotifier and can be used as a Set directly.
GetValue
Encapsulates a ValueNotifier.
GetVsync
Encapsulates an Animation.
GetVsyncDouble
Encapsulates an AnimationController.
GetVsyncValue
Encapsulates a ValueAnimation.

Extensions

GetHooked on Get<Object?, V>
Allows the hook functions defined in Ref to access a Get object's ValueListenable.
ToggleValue on GetValue<bool>
Toggles a boolean GetValue.
VsyncRef on ComputeRef

Typedefs

GetAny = Get<Object?, ValueRef>
A generic type implemented by all Get objects.
GetT<T> = Get<T, ValueListenable<T>>
Shorthand for specifying a Get object's first type argument.
GetV<V extends ValueRef> = Get<Object?, V>
Shorthand for specifying a Get object's second type argument.
GetVsyncA<A extends Animation<Object?>> = GetVsync<Object?, A>
Shorthand for specifying a GetVsync object's second type argument.
GetVsyncAny = GetVsync<Object?, Animation<Object?>>
A generic type implemented by all GetVsync objects.
GetVsyncT<T> = GetVsync<T, Animation<T>>
Shorthand for specifying a GetVsync object's first type argument.
RefComputer<Result> = Result Function(ComputeRef ref)

Exceptions / Errors

GetScopeError
Might as well use a fun little class for the scope errors!