it<T> static method
Encapsulates a ValueNotifier.
See also:
- Get.vsyncValue, which creates smooth transitions between values, by using a Vsync to change gradually each animation frame.
Implementation
@factory
static GetValue<T> it<T>(T initialValue) => GetValue._(_ValueNotifier(initialValue));