GetVsyncDouble extension type
Encapsulates an AnimationController.
- on
- Implemented types
Properties
- addListener → void
-
Don't add a listener directly!
Prefer using Ref.watch or something similar.
no setterinherited
- addStatusListener → void
-
Don't add a listener directly!
Prefer using Ref.watch or something similar.
no setterinherited
- animationBehavior → AnimationBehavior
-
The behavior of the controller when AccessibilityFeatures.disableAnimations
is true.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isAnimating → bool
-
Whether this animation is running in either direction.
no setterinherited
- isCompleted → bool
-
Whether this animation is stopped at the end.
no setterinherited
- isDismissed → bool
-
Whether this animation is stopped at the beginning.
no setterinherited
- isForwardOrCompleted → bool
-
Whether the current aim of the animation is toward completion.
no setterinherited
- lastElapsedDuration → Duration?
-
The amount of time that has passed between the time the animation started
and the most recent tick of the animation.
no setter
- lowerBound → double
-
The value at which this animation is deemed to be dismissed.
no setter
- maybeVsync → Vsync?
-
The Vsync associated with this animation.
no setterinherited
- removeListener → void
-
Don't remove a listener directly!
Prefer using Ref.watch or something similar.
no setterinherited
- removeStatusListener → void
-
Don't remove a listener directly!
Prefer using Ref.watch or something similar.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → AnimationStatus
-
The current status of this animation.
no setterinherited
- upperBound → double
-
The value at which this animation is deemed to be completed.
no setter
- value ↔ double
-
The current value of the object. When the value changes, the callbacks
registered with addListener will be invoked.
getter/setter pairinherited-getter
- velocity → double
-
The rate of change of value per second.
no setter
Methods
-
animateBack(
double target, {Duration? duration, Curve curve = Curves.linear}) → TickerFuture - Drives the animation from its current value to the given target, "backward".
-
animateTo(
double target, {Duration? duration, Curve curve = Curves.linear}) → TickerFuture - Drives the animation from its current value to the given target, "forward".
-
animateWith(
Simulation simulation) → TickerFuture - Drives the animation according to the given simulation.
-
drive<
U> (Animatable< U> child) → Animation<U> -
Chains a Tween (or CurveTween) to this Animation.
inherited
-
fling(
{double velocity = 1.0, SpringDescription? springDescription, AnimationBehavior? animationBehavior}) → TickerFuture - Drives the animation with a spring (within lowerBound and upperBound) and initial velocity.
-
forward(
{double? from}) → TickerFuture - Starts running this animation forwards (towards the end).
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
repeat(
{double? min, double? max, bool reverse = false, Duration? period, int? count}) → TickerFuture - See AnimationController.repeat.
-
reset(
) → void - Sets the controller's value to lowerBound, stopping the animation (if in progress), and resetting to its beginning point, or dismissed state.
-
reverse(
{double? from}) → TickerFuture - Starts running this animation in reverse (towards the beginning).
-
stop(
{bool canceled = true}) → void - Stops running this animation.
-
toggle(
{double? from}) → TickerFuture - Toggles the direction of this animation, based on whether it isForwardOrCompleted.
-
toString(
) → String -
A string representation of this object.
inherited
-
toStringDetails(
) → String -
Provides a string describing the status of this object, but not including
information about the object itself.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited