GetVsyncValue<T>
extension type
Encapsulates a ValueAnimation.
- on
- Implemented types
-
- GetVsync<
T, ValueAnimation< T> >
- GetVsync<
Properties
- addListener → void
-
Don't add a listener directly!
Prefer using Ref.watch or something similar.
no setterinherited
- addStatusListener → void
-
Don't add a listener directly!
Prefer using Ref.watch or something similar.
no setterinherited
- animationBehavior → AnimationBehavior
-
The behavior of the controller when AccessibilityFeatures.disableAnimations
is true.
no setter
- curve ↔ Curve
-
Determines how quickly the animation speeds up and slows down.
getter/setter pair
- duration ↔ Duration
-
The length of time this animation should last.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- isAnimating → bool
-
Whether this animation is running in either direction.
no setterinherited
- isCompleted → bool
-
Whether this animation is stopped at the end.
no setterinherited
- isDismissed → bool
-
Whether this animation is stopped at the beginning.
no setterinherited
- isForwardOrCompleted → bool
-
Whether the current aim of the animation is toward completion.
no setterinherited
- maybeVsync → Vsync?
-
The Vsync associated with this animation.
no setterinherited
- removeListener → void
-
Don't remove a listener directly!
Prefer using Ref.watch or something similar.
no setterinherited
- removeStatusListener → void
-
Don't remove a listener directly!
Prefer using Ref.watch or something similar.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → AnimationStatus
-
The current status of this animation.
no setterinherited
- value ↔ T
-
The current value of the object. When the value changes, the callbacks
registered with addListener will be invoked.
getter/setter pairinherited-getter
Methods
-
animateTo(
T target, {T? from, Duration? duration, Curve? curve}) → TickerFuture - Triggers an animation, and returns a TickerFuture that completes when it finishes.
-
drive<
U> (Animatable< U> child) → Animation<U> -
Chains a Tween (or CurveTween) to this Animation.
inherited
-
jumpTo(
T target) → void - Immediately set a new value.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
stop(
{bool canceled = true}) → void - Stops the animation.
-
toString(
) → String -
A string representation of this object.
inherited
-
toStringDetails(
) → String -
Provides a string describing the status of this object, but not including
information about the object itself.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited