- Implemented types
- Available extensions
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
compute<
Result> (RefComputer< Result> callback) → Result -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
read<
G extends GetAny> (G get, {bool autoVsync = true, bool useScope = true}) → G -
inherited
-
select<
Result, T> (GetT< T> get, Result selector(T value), {bool autoVsync = true, bool useScope = true}) → Result -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
vsync<
G extends GetAny> (G get, {bool useScope = true}) → G -
Available on ComputeRef, provided by the VsyncRef extension
-
watch<
T> (GetT< T> get, {bool autoVsync = true, bool useScope = true}) → T -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited