ref/hooked/hook_functions library
Classes
-
ObjectRef<
T> - A class that stores a single value.
Constants
-
useAnimation
→ const T Function<
T>(ValueListenable< T> valueListenable, {bool watching = true}) - Animations are just ValueListenables with an AnimationStatus!
Functions
-
useAnimationStatus<
T> (Animation< Object?> animation, T statusListener(AnimationStatus status)) → T -
Calls the
statusListenerwhenever the Animation.status changes. -
useEffect(
ValueGetter< VoidCallback?> effect, {Object? key}) → void -
Invokes the
effectcallback, and calls it again whenever thekeychanges. -
useListenable<
L extends Listenable?> (L listenable, {bool watching = true}) → L - Subscribes to a Listenable and marks the widget as needing build whenever the listener is called.
-
useMemoized<
T> (ValueGetter< T> valueGetter, {Object? key}) → T - Caches the instance of a complex object.
-
useRef<
T> (T initialValue, {Object? key}) → ObjectRef< T> - Creates an object containing a property which can be mutated without triggering rebuilds.
-
useValueListenable<
T> (ValueListenable< T> valueListenable, {bool watching = true}) → T - Subscribes to a ValueListenable and returns its value.