HookData<Result> class
abstract
This class makes it easier for a Hook to work with a complex data model.
- Annotations
Properties
Methods
-
createHook(
) → Hook< Result, HookData< Result> > - Generally returns an empty constructor for a Hook subclass.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited