GetFromContext extension
Allows accessing the relevant value from an ancestor GetScope in a reasonably concise manner.
- on
Methods
-
get<
T, V extends ValueListenable< (T> >Get< T, V> get, {bool createDependency = true, bool throwIfMissing = false}) → Get<T, V> -
Available on BuildContext, provided by the GetFromContext extension
Allows accessing the relevant value from an ancestor GetScope in a reasonably concise manner.