GetScope class
A widget that allows setting Substitutions for Get objects.
Ref static methods will point to the objects specified in the substitutes by default.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- GetScope
Constructors
Properties
- child → Widget
-
The widget below this one in the tree.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inherit → bool
-
Whether this GetScope should also include substitutes from an ancestor scope,
if applicable.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
substitutes
→ Iterable<
SubAny> -
An iterable (typically a Set) that points Get objects to new values.
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< GetScope> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
add(
BuildContext context, {Map< GetAny, GetAny> getObjects = const {}, Map<GetAny, ValueRef> listenables = const {}, bool throwIfMissing = true}) → void - Adds more substitutions to the existing ancestor GetScope.
-
maybeOf<
G extends GetAny> (BuildContext context, G get, {bool createDependency = true}) → G? - If the Get object is overridden in an ancestor Ref, returns that object.
-
of<
G extends GetAny> (BuildContext context, G get, {bool createDependency = true, bool throwIfMissing = false}) → G - Returns the Get object that overrides this one.