autoDispose property
Whether to automatically call ChangeNotifier.dispose when the substitution is no longer part of an active GetScope.
Defaults to true, but this value is ignored if the notifier is identified
as a DisposeGuard instance.
Implementation
final bool autoDispose;