AnimationView<T>
extension type
Provides a "view" of an Animation object, without exposing methods for adding/removing listeners.
Constructors
-
AnimationView(Animation<
T> _animation)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isAnimating → bool
-
Whether this animation is running in either direction.
no setter
- isCompleted → bool
-
Whether this animation is stopped at the end.
no setter
- isDismissed → bool
-
Whether this animation is stopped at the beginning.
no setter
- isForwardOrCompleted → bool
-
Whether the current aim of the animation is toward completion.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → AnimationStatus
-
The current status of this animation.
no setter
- value → T
-
The current value of the animation.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
toStringDetails(
) → String - Provides a string describing the status of this object, but not including information about the object itself.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited