AsyncController<T> class
An AsyncNotifier that can process Future and Stream objects.
- Inheritance
-
- Object
- AsyncNotifier<
T> - AsyncController
Constructors
-
AsyncController({AsyncValueGetter<
T> ? futureCallback, StreamCallback<T> ? streamCallback, T? initialData, bool cancelOnError = false, bool notifyOnCancel = false}) - Creates an AsyncNotifier that can process Future and Stream objects.
Properties
- cancelOnError ↔ bool
-
Whether a StreamSubscription should end if it encounters an error.
getter/setter pair
- connectionState ↔ ConnectionState
-
Current state of connection to the asynchronous computation.
getter/setter pairinherited
-
futureCallback
↔ AsyncValueGetter<
T> ? -
Can be invoked to update the AsyncNotifier based on a Future.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- initialData ↔ T?
-
getter/setter pair
- notifyOnCancel ↔ bool
-
Whether the AsyncNotifier should send a notification when
the connection ends.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
streamCallback
↔ StreamCallback<
T> ? -
Can be invoked to update the AsyncNotifier based on a Stream.
getter/setter pair
-
value
↔ AsyncSnapshot<
T> -
The current value stored in this notifier.
getter/setter pairinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
clear(
{bool? notify}) → void - Cancels the StreamSubscription and ignores the Future if applicable.
-
dispose(
) → void -
Discards any resources used by the object. After this is called, the
object is not in a usable state and should be discarded (calls to
addListener will throw after the object is disposed).
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
setFuture(
[Future< T> ? future]) → void - Invokes the stored futureCallback, or alternatively can accept a new Future object.
-
setStream(
[Stream< T> ? stream]) → void - Invokes the stored StreamCallback, or alternatively can accept a new Stream object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited