SchedulerBuilding extension
Provides an estimate regarding whether a build is imminent.
This allows classes such as ProxyNotifier to decide whether to fire immediately or use Future.microtask to mitigate duplicate notifications.
Properties
- building → bool
-
Available on SchedulerBinding, provided by the SchedulerBuilding extension
Provides an estimate regarding whether a build is imminent.no setter