utils/value_animation library
Classes
- Simulation
- The base class for all simulations.
- SpringDescription
- Structure that describes a spring's constants.
- TickerFuture
- An object representing an ongoing Ticker sequence.
- TickerProvider
- An interface implemented by classes that can vend Ticker objects.
- ToggleAnimation
- An animation controller that toggles between two states.
-
ValueAnimation<
T> - A ValueListenable whose value updates each frame over the specified duration to create a continuous visual transition.
Typedefs
-
LerpCallback<
T> = T? Function(T a, T b, double t) - Function signature for linear interpolation.