widgets library
Classes
- AppBarConst
- A Material Design app bar.
- ClippedDecoration
- A variation of DecoratedBox that allows specifying a clipBehavior and re-renders without any need to rebuild a widget subtree.
- HookBuilder
-
A HookWidget that delegates its
buildto a callback. - HookWidget
- A variation of a StatelessWidget that can call Hook functions in its HookWidget.build method.
- ImmutableSubtree
-
Those darn times when 1 widget makes it so the entire thing can't be
const. - RawText
- A RenderObjectWidget that can display a String of text.
- RefPaint
- A variation of CustomPaint that interfaces with Get objects.
- RenderClippedDecoration
- Paints a Decoration.
-
RenderGet<
Render extends RenderObject> - A simple widget that subscribes to a Get object and updates a RenderObject accordingly.
- RenderGetBase
- Extend this class to create a widget with a single child.
-
RenderScopedGetBase<
T> - Extend this class to create a widget with a single child.
- StatefulHookWidget
- A variation of a StatefulWidget that can call Hook functions in its State.build method.
-
TextGetter<
T> - A widget displaying a string representation of a Get object's value.
Enums
- MaterialTextStyle
- Selects a TextStyle from the ThemeData.textTheme.
Mixins
- TextStyleSelector
- An object that resolves to a TextStyle by selecting from a TextTheme.
Extension Types
- PainterRef
- A reference used in RefPaint.hitTest calls.
- PaintingRef
- An interface used by RefPaint.paint and RefPaint.buildSemantics.
Typedefs
- RefPaintCallback = void Function(PaintingRef ref)
- Signature for the callback within a RefPaint widget that paints a UI element, using a Canvas retrieved via PaintingRef.stageCanvas.
- RefPaintHitTest = bool? Function(PainterRef ref, Offset location)
-
Signature for a callback that determines whether a RefPaint widget
will absorb a hit test. If the function or its output is
null, the widget defers to the default behavior as defined in RefPaint.hitTest. -
RefPaintSemanticsBuilder
= List<
CustomPainterSemantics> Function(PaintingRef ref) - Builds semantics information describing the picture drawn by a RefPaintCallback. Each CustomPainterSemantics in the returned list is converted into a SemanticsNode by copying its properties.
- SubtreeBuilder = Widget Function(BuildContext context, Object? key)
-
Builds a Widget, given the
keyfrom the ImmutableSubtree.placeholder.