merge method
Unlike TextStyle.merge, the object returned by this method does not support stable equality checks.
Prefer calling resolve and modifying the result, or changing
the TextTheme directly (e.g. by creating a Theme widget
with the desired configuration).
Implementation
@override
TextStyle merge(TextStyle? other) => switch (other) {
null => this,
TextStyleSelector() => _SelectorCallback((theme) => select(theme).merge(other.select(theme))),
TextStyle() => _SelectorCallback((theme) => select(theme).merge(other)),
};