PainterRef extension type
A reference used in RefPaint.hitTest calls.
See also: PaintingRef, a subtype of PainterRef that
RefPaint.paint and RefPaint.buildSemantics interface with.
- on
-
- _RefPainterElement
- Implemented types
- Implementers
Properties
- context → BuildContext
-
Use caution when accessing the BuildContext,
since any update from an InheritedWidget will trigger
a repaint unconditionally.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → Size
-
The Size of the painter's canvas.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
read<
G extends GetAny> (G get, {bool createDependency = true, bool throwIfMissing = false}) → G - Returns the relevant Get object based on the current context.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited