read<G extends GetAny> method
Returns the relevant Get object based on the current context.
This will be identical to the input, unless a Substitution was made in the ancestor GetScope.
Implementation
G read<G extends GetAny>(G get, {bool createDependency = true, bool throwIfMissing = false}) {
return GetScope.of(
context,
get,
createDependency: createDependency,
throwIfMissing: throwIfMissing,
);
}